@@ -15,6 +15,12 @@ func OpenExplorer(url string) {
 	case "darwin": // macOS
 		cmd = exec.Command("open", url)
 	default: // Linux
+		// 如果在 Termux 中运行则停止，因为 exec.Command 可能会触发 SIGSYS: bad system call
+		// https://github.com/docker/compose/issues/10511#issuecomment-1531453435
+		if isTermux() {
+			return
+		}
+
 		cmd = exec.Command("xdg-open", url)
 	}
 
